.. _testing_module:

:mod:`pyramid.testing`
==========================

.. automodule:: pyramid.testing

  .. autofunction:: registerDummySecurityPolicy

  .. autofunction:: registerResources

  .. autofunction:: registerEventListener

  .. autofunction:: registerTemplateRenderer

  .. autofunction:: registerView

  .. autofunction:: registerUtility

  .. autofunction:: registerAdapter

  .. autofunction:: registerSubscriber

  .. autofunction:: registerRoute

  .. autofunction:: registerSettings

  .. autofunction:: setUp

  .. autofunction:: tearDown

  .. autofunction:: cleanUp

  .. autoclass:: DummyResource
     :members:

  .. autoclass:: DummyRequest
     :members:

  .. autoclass:: DummyTemplateRenderer
     :members:



